import os
import numpy as np
import opal
import matplotlib.pyplot as plt
from scipy.signal import find_peaks

def analyze_stat_file():
    # Detect the current directory
    current_dir = os.getcwd()

    # Find the .stat file
    stat_files = [file for file in os.listdir(current_dir) if file.endswith('.stat')]
    #if not stat_files:
        #print("No .stat file found in the directory:", current_dir)
        #return None, None, None

    # Use the first found .stat file
    stats_file = opal.datasets.StatDataset.StatDataset(current_dir, stat_files[0])
    positions = stats_file.getData('s')
    rms_x = stats_file.getData('rms_x') * 1e3  # Convert to mm
    emit_x = stats_file.getData('emit_x') * 1e6  # Convert to mm rad
    
    return positions, rms_x, emit_x

# Call the function to perform analysis
positions, rms_x, emit_x = analyze_stat_file()

# Filter data based on the condition position > 0.35 (include after Gun exit)
filtered_indices = positions > 0.35
filtered_rms_x = rms_x[filtered_indices]
filtered_emit_x = emit_x[filtered_indices]
filtered_positions = positions[filtered_indices]

# Find peaks in the filtered emit_x data & minima in the filtered rms_x data

peaks_emit_x, _ = find_peaks(-filtered_emit_x, prominence=0.001)  # Adjust prominence threshold as needed
minima_rms_x, _ = find_peaks(-filtered_rms_x, prominence=0.001)  # Adjust prominence threshold as needed

# Find the emit_x peak closest to the beam size minima in terms of its position

closest_peak_position = filtered_positions[peaks_emit_x][np.argmin(np.abs(filtered_positions[peaks_emit_x] - filtered_positions[minima_rms_x][0]))]
delta_positions = closest_peak_position - filtered_positions[minima_rms_x][0]

# Save the emittance peak into a file

np.savetxt("emit.dat", [np.abs(4-closest_peak_position)], fmt='%.8f')#, header='Emittance peak position')
np.savetxt("rmsx.dat", [np.abs(4-filtered_positions[minima_rms_x])], fmt='%.8f')#, header='Beam size minima position')
np.savetxt("delta.dat", [np.abs(delta_positions)], fmt='%.8f')#, header='Delta position')


